QASC is a question-answering dataset with a focus on sentence composition. It
consists of 9,980 8-way multiple-choice questions about grade school science
(8,134 train, 926 dev, 920 test), and comes with a corpus of 17M sentences.
